@@ -32,7 +32,7 @@ class Platform:
             schema=schema,
             spark_session=spark_session,
         )
-        print(data_frame)
+        print(data_frame.show())
 
     def silver_to_gold(self):
         pass
